==> haskell-xml-conduit-1.9.1.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-conduit
version:              1.9.1.0
visibility:           public
id:                   xml-conduit-1.9.1.0-6WQjy8A5wcN4DBY0h2CPs2
key:                  xml-conduit-1.9.1.0-6WQjy8A5wcN4DBY0h2CPs2
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  0e6d481d616dccf353e7ef09eb827fda
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-8.10.4/site-local/xml-conduit-1.9.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/xml-conduit-1.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/xml-conduit-1.9.1.0
hs-libraries:         HSxml-conduit-1.9.1.0-6WQjy8A5wcN4DBY0h2CPs2
depends:
    attoparsec-0.13.2.5-GizkWPNym1tDxXu7xbn7bA base-4.14.1.0
    blaze-html-0.9.1.2-2yTsGIkXtmWB3Lt1pdMScK
    blaze-markup-0.8.2.8-HUMs0SpgmI6A2W3VdBZbe5 bytestring-0.10.12.0
    conduit-1.3.4.1-1jCUVqQRd77KYcBcbXkc8K
    conduit-extra-1.3.5-GF4oF3JHnms2XKuLC909s4 containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 deepseq-1.4.4.0
    resourcet-1.2.4.2-5f6n3flQq1pLZgZQ1NQBig text-1.2.4.1
    transformers-0.5.6.2 xml-types-0.3.8-9NvGZWCLGJCFNI7RY3QJQ9

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.9.1.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-conduit
version:              1.9.1.0
visibility:           public
id:                   xml-conduit-1.9.1.0-GJjF8Fzb17A6kQtINCxmWS
key:                  xml-conduit-1.9.1.0-GJjF8Fzb17A6kQtINCxmWS
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>

stability:            Stable
homepage:             http://github.com/snoyberg/xml
synopsis:
    Pure-Haskell utilities for dealing with XML with the conduit package.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.

category:             XML, Conduit
abi:                  7fbece5d5927284b8f5c57110815aa4f
exposed:              True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved

hidden-modules:       Text.XML.Stream.Token
import-dirs:          /usr/lib/ghc-8.10.4/site-local/xml-conduit-1.9.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/xml-conduit-1.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/xml-conduit-1.9.1.0
hs-libraries:         HSxml-conduit-1.9.1.0-GJjF8Fzb17A6kQtINCxmWS
depends:
    attoparsec-0.13.2.5-J6b14THaxvY185NePfXLop base-4.14.1.0
    blaze-html-0.9.1.2-LrlSO9sOLE59wXedG2axxL
    blaze-markup-0.8.2.8-AbmEv0BkcvKLCOElcztvLF bytestring-0.10.12.0
    conduit-1.3.4.1-BsPMp3atGtrJXb8lJ0hFF8
    conduit-extra-1.3.5-UoTKH2Tch1Bcb4lcASpvK containers-0.6.2.1
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 deepseq-1.4.4.0
    resourcet-1.2.4.2-7jh3WeBmwav3Q3gOaWNv32 text-1.2.4.1
    transformers-0.5.6.2 xml-types-0.3.8-9NvGZWCLGJCFNI7RY3QJQ9

haddock-interfaces:   /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html:         /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
